Index: /fact/Evidence/GUI.h
===================================================================
--- /fact/Evidence/GUI.h	(revision 17038)
+++ /fact/Evidence/GUI.h	(revision 17039)
@@ -78,5 +78,6 @@
 	QwtPlotMarker *Stats;
 	class EddLegend *Legend;
- 	
+ 	bool MouseMoved;
+
   public:
     EddBasePlot(QWidget * = NULL);
@@ -98,5 +99,7 @@
     void HandleZoom(const QRectF &);
 	void MouseSelection(const QPolygon &);
-	void mouseDoubleClickEvent(QMouseEvent *); 
+	void mousePressEvent(QMouseEvent *); 
+	void mouseReleaseEvent(QMouseEvent *); 
+	void mouseMoveEvent(QMouseEvent *); 
 	void contextMenuEvent(QContextMenuEvent *);
     void MenuSetUpdateRate();        
@@ -166,5 +169,4 @@
 
   private:
-    //EddDateScale *Scale;
 	QwtLegend *Legend;
 	QTimer *SingleShot;
@@ -185,5 +187,4 @@
    
   private slots:
-    void ScaleUpdate();
     void MenuPasteService();
 	void MenuShowLastHour();

Index: /fact/Evidence/GUI.cc
===================================================================
--- /fact/Evidence/GUI.cc	(revision 17038)
+++ /fact/Evidence/GUI.cc	(revision 17039)
@@ -339,6 +339,5 @@
   // Horizontal time scale
   setAxisScaleDraw(QwtPlot::xBottom, new EddDateScale());
-  connect(axisWidget(QwtPlot::xBottom), SIGNAL(scaleDivChanged()), SLOT(ScaleUpdate()));
-
+ 
   // Additonal context menu items
   QAction* Action = Menu->addAction("Paste service", this, SLOT(MenuPasteService()));
@@ -424,18 +423,4 @@
 	NewData = true;
   }
-}
-
-// Add text indicating time range to plot
-void EddPlot::ScaleUpdate() {
-
-  QwtText Text;
-  QFont Font;
-  
-  // Set footer
-  Text = QDateTime::fromMSecsSinceEpoch(axisScaleDiv(QwtPlot::xBottom).lowerBound()).toString("d-MMM-yyyy hh:mm:ss") + " to " + QDateTime::fromMSecsSinceEpoch(axisScaleDiv(QwtPlot::xBottom).upperBound()).toString("d-MMM-yyyy hh:mm:ss");
-
-  Font.setPointSize(6);
-  Text.setFont(Font);
-  setFooter(Text);
 }
 
@@ -702,4 +687,17 @@
   else setCanvasBackground(EddPlotBackgroundColor);
 
+  // Set footer
+  QwtText Text;
+  QFont Font;
+  
+  Text = QDateTime::fromMSecsSinceEpoch(axisScaleDiv(QwtPlot::xBottom).lowerBound()).toString("d-MMM-yyyy hh:mm:ss") + " to " +
+	QDateTime::fromMSecsSinceEpoch(axisScaleDiv(QwtPlot::xBottom).upperBound()).toString("d-MMM-yyyy hh:mm:ss") +
+	(StripAction->isChecked() ? " (Stripchart)" : "");
+
+  Font.setPointSize(6);
+  Text.setFont(Font);
+  setFooter(Text); // For EddScope (not a history plot, no time scale) this action is removed
+  
+  // Recalculate statistics
   ReDoStats();
 }
@@ -836,13 +834,25 @@
 }
 
-// Double clicking hightlights curve
-void EddBasePlot::mouseDoubleClickEvent (QMouseEvent *Event) {
-	
+// Mouse events: Release click highlights curve if mouse did not move (which is zoom)
+void EddBasePlot::mousePressEvent(QMouseEvent *) {
+
+  MouseMoved = false;
+}
+
+void EddBasePlot::mouseMoveEvent(QMouseEvent *) {
+
+  MouseMoved = true;
+}
+
+void EddBasePlot::mouseReleaseEvent(QMouseEvent *Event) {
+  
   double Dist, MinDistance = std::numeric_limits<double>::infinity();
   int Index = -1;
 
+  if (Event->button() != Qt::LeftButton || MouseMoved) return;
+
   // Check which curve is closest
   for (int i=0; i<Items.size(); i++) {
-	if (Items[i].Signal->closestPoint(Event->pos(), &Dist) != -1 && Dist < MinDistance) {
+	if (Items[i].Signal->closestPoint(canvas()->mapFromGlobal(QCursor::pos()), &Dist) != -1 && Dist < MinDistance) {
 	  MinDistance = Dist;
 	  Index = i;
@@ -943,5 +953,5 @@
     "Pan\tShift and left mouse button\n\n"
 	"ESC cancels selection\n"
-	"Double-clicking highlights nearest curve\n"
+	"Clicking near a curve or on legend highlights\n"
     "Cursor keys move mouse\n\n"
 	"Statistics are calculated over the current x axis extend\n\n"
@@ -1008,15 +1018,11 @@
 }
 
 // Handling of mouse release event: Open history
 void EddLegendLabel::mouseReleaseEvent(QMouseEvent *Event) {
 
   if (Event->button() != Qt::LeftButton) return;
   
-  QString D(text().text());
-  D.replace(':',' ');
-  QStringList A = D.split(" ");
-  
-  OpenHistory(A[0].toAscii().data(), A[1].toInt());
-}
+  ThickLineAction->toggle(); 
+ }
 
 // Menu: Open history plot
@@ -1008,15 +1018,11 @@
 }
 
-// Handling of mouse release event: Open history
+// Handling of mouse release event: Mark line
 void EddLegendLabel::mouseReleaseEvent(QMouseEvent *Event) {
 